@@ -32,8 +32,6 @@
 #include "internal.h"
 #include "librtas.h"
 
-#define CALL_AGAIN 1
-
 int dbg_lvl = 0;
 static uint64_t rtas_timeout_ms;
 
@@ -65,7 +63,8 @@ int sanity_check(void)
  *	CALL_AGAIN	if the status is delay related
  *	RTAS_TIMEOUT if the requested timeout has been exceeded
  */
-static unsigned int handle_delay(int status, uint64_t * elapsed)
+__attribute__((visibility("hidden")))
+unsigned int handle_delay(int status, uint64_t * elapsed)
 {
 	int order = status - EXTENDED_DELAY_MIN;
 	unsigned long ms = 0;
@@ -76,8 +75,8 @@ static unsigned int handle_delay(int status, uint64_t * elapsed)
 		for (ms = 1; order > 0; order--)
 			ms = ms * 10;
 	} else if (status == RC_BUSY) {
-		/* Regular Delay */
-		ms = 1;
+		/* Retry */
+		return CALL_AGAIN;
 	} else {
 		/* Not a delay return code */
 		return 0;
@@ -95,7 +94,7 @@ static unsigned int handle_delay(int status, uint64_t * elapsed)
 
 	dbg("Return status %d, delaying for %lu ms\n", status, ms);
 	usleep(ms * 1000);
-	return 1;
+	return CALL_AGAIN;
 }
 
 /**
@@ -213,7 +212,8 @@ static int _rtas_call(int delay_handling, int token, int ninputs,
 	return 0;
 }
 
-static int rtas_call_no_delay(const char *name, int ninputs, int nrets, ...)
+__attribute__((visibility("hidden")))
+int rtas_call_no_delay(const char *name, int ninputs, int nrets, ...)
 {
 	va_list ap;
 	int rc, token;
@@ -229,7 +229,8 @@ static int rtas_call_no_delay(const char *name, int ninputs, int nrets, ...)
 	return rc;
 }
 
-static int rtas_call(const char *name, int ninputs, int nrets, ...)
+__attribute__((visibility("hidden")))
+int rtas_call(const char *name, int ninputs, int nrets, ...)
 {
 	va_list ap;
 	int rc, token;
@@ -673,44 +674,6 @@ int rtas_get_sensor(int sensor, int index, int *state)
 	return rc ? rc : status;
 }
 
-/**
- * rtas_get_sysparm
- * @brief Interface to the ibm,get-system-parameter rtas call
- *
- * On successful completion the data parameter will contain the system
- * parameter results
- *
- * @param parameter system parameter to retrieve
- * @param length data buffer length
- * @param data reference to buffer to return parameter in
- * @return 0 on success, !0 otherwise
- */
-int rtas_get_sysparm(unsigned int parameter, unsigned int length, char *data)
-{
-	uint32_t kernbuf_pa;
-	void *kernbuf;
-	int rc, status;
-
-	rc = sanity_check();
-	if (rc)
-		return rc;
-
-	rc = rtas_get_rmo_buffer(length, &kernbuf, &kernbuf_pa);
-	if (rc)
-		return rc;
-
-	rc = rtas_call("ibm,get-system-parameter", 3, 1, htobe32(parameter),
-		       htobe32(kernbuf_pa), htobe32(length), &status);
-
-	if (rc == 0)
-		memcpy(data, kernbuf, length);
-
-	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, length);
-
-	dbg("(%u, %u, %p) = %d\n", parameter, length, data, rc ? rc : status);
-	return rc ? rc : status;
-}
-
 /**
  * rtas_get_time
  * @brief Interface to get-time-of-day rtas call
@@ -752,73 +715,6 @@ int rtas_get_time(uint32_t *year, uint32_t *month, uint32_t *day,
 	return rc ? rc : status;
 }
 
-/**
- * rtas_get_vpd
- * @brief Interface to the ibm,get-vpd rtas call
- *
- * @param loc_code location code
- * @param workarea additional args to rtas call
- * @param size
- * @param sequence
- * @param seq_next
- * @param bytes_ret
- * @return 0 on success, !0 otherwise
- */
-int rtas_get_vpd(char *loc_code, char *workarea, size_t size,
-		 unsigned int sequence, unsigned int *seq_next,
-		 unsigned int *bytes_ret)
-{
-	uint32_t kernbuf_pa;
-	uint32_t loc_pa = 0;
-	uint32_t rmo_pa = 0;
-	uint64_t elapsed = 0;
-	void *kernbuf;
-	void *rmobuf;
-	void *locbuf;
-	int rc, status;
-
-	rc = sanity_check();
-	if (rc)
-		return rc;
-
-	rc = rtas_get_rmo_buffer(size + WORK_AREA_SIZE, &rmobuf, &rmo_pa);
-	if (rc)
-		return rc;
-
-	kernbuf = rmobuf + WORK_AREA_SIZE;
-	kernbuf_pa = rmo_pa + WORK_AREA_SIZE;
-	locbuf = rmobuf;
-	loc_pa = rmo_pa;
-
-	/* If user didn't set loc_code, copy a NULL string */
-	strncpy(locbuf, loc_code ? loc_code : "", WORK_AREA_SIZE);
-
-	*seq_next = htobe32(sequence);
-	do {
-		sequence = *seq_next;
-		rc = rtas_call_no_delay("ibm,get-vpd", 4, 3, htobe32(loc_pa),
-				  htobe32(kernbuf_pa), htobe32(size),
-				  sequence, &status, seq_next,
-				  bytes_ret);
-		if (rc < 0)
-			break;
-
-		rc = handle_delay(status, &elapsed);
-	} while (rc == CALL_AGAIN);
-
-	if (rc == 0)
-		memcpy(workarea, kernbuf, size);
-
-	(void) rtas_free_rmo_buffer(rmobuf, rmo_pa, size + WORK_AREA_SIZE);
-
-	*seq_next = be32toh(*seq_next);
-	*bytes_ret = be32toh(*bytes_ret);
-
-	dbg("(%s, 0x%p, %zu, %u) = %d, %u, %u\n", loc_code ? loc_code : "NULL",
-	    workarea, size, sequence, status, *seq_next, *bytes_ret);
-	return rc ? rc : status;
-}
-
 /**
  * rtas_lpar_perftools
  * @brief Interface to the ibm,lpar-perftools rtas call
@@ -1175,52 +1071,6 @@ int rtas_set_poweron_time(uint32_t year, uint32_t month, uint32_t day,
 	return rc ? rc : status;
 }
 
-/**
- * rtas_set_sysparm
- * @brief Interface to the ibm,set-system-parameter rtas call
- *
- * @param parameter
- * @param data
- * @return 0 on success, !0 otherwise
- */
-int rtas_set_sysparm(unsigned int parameter, char *data)
-{
-	uint32_t kernbuf_pa;
-	void *kernbuf;
-	int rc, status;
-	uint16_t size;
-
-	rc = sanity_check();
-	if (rc)
-		return rc;
-	/*
-	 * We have to copy the contents of @data to a RMO buffer. The
-	 * caller has encoded the data length in the first two bytes
-	 * of @data in MSB order, and we can't assume any
-	 * alignment. So interpret @data as:
-	 *
-	 * struct {
-	 *     unsigned char len_msb;
-	 *     unsigned char len_lsb;
-	 *     char [(len_msb << 8) + len_lsb];
-	 * }
-	 */
-	size = 2 + (((unsigned char)data[0] << 8) | (unsigned char)data[1]);
-	rc = rtas_get_rmo_buffer(size, &kernbuf, &kernbuf_pa);
-	if (rc)
-		return rc;
-
-	memcpy(kernbuf, data, size);
-
-	rc = rtas_call("ibm,set-system-parameter", 2, 1, htobe32(parameter),
-		       htobe32(kernbuf_pa), &status);
-
-	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, size);
-
-	dbg("(%u, %p) = %d\n", parameter, data, rc ? rc : status);
-	return rc ? rc : status;
-}
-
 /**
  * rtas_set_time
  * @brief Interface to the set-time-of-day rtas call
